﻿-- Author      : Zimbu
-- Create Date : 4/20/2008 4:06:50 PM

DailyTrackerFrame_OutOfDateText = "";

function DailyTrackerBtnClose_OnClick()
	DailyTrackerFrame:Hide();
end

function DailyTrackerBtnRefresh_OnClick()
	-- for now just use the comm to request our quests
	DailyTrackerComm:SendCategoryRequest("DAILYNORMAL", "DAILYHEROIC", "DAILYFISHING", "DAILYCOOKING", "DAILYBATTLEGROUND");	
end

function DailyTracker:ToggleFrame()
	if DailyTrackerFrame:IsShown() then
		DailyTrackerFrame:Hide();
	else
		DailyTrackerFrame:Show();
	end
end

function DailyTracker:LoadQuest(quest, objQuestName, objLocation)
	objQuestName:SetText( DailyTrackerStrings.Unknown );
	objLocation:SetText( "" );
	
	if quest then
		objQuestName:SetText( quest.Title );
		if quest.Location then
			objLocation:SetText( quest.Location );
		end
	end
end

function DailyTracker:RefreshFrame()
	self:LoadQuest( self:GetCurrentQuest("DAILYNORMAL"), DailyNormal_QuestName, DailyNormal_Location );	
	self:LoadQuest( self:GetCurrentQuest("DAILYHEROIC"), DailyHeroic_QuestName, DailyHeroic_Location );
	self:LoadQuest( self:GetCurrentQuest("DAILYFISHING"), DailyFishing_QuestName, DailyFishing_Location );
	self:LoadQuest( self:GetCurrentQuest("DAILYCOOKING"), DailyCooking_QuestName, DailyCooking_Location );
	self:LoadQuest( self:GetCurrentQuest("DAILYBATTLEGROUND"), DailyBattleground_QuestName, DailyBattleground_Location );
end

function DailyTrackerLatestVersion_OnEnter()
	local latestVersion = DailyTrackerComm.LatestVersion;
	
	if latestVersion > DailyTracker:GetRevision() then
		GameTooltip:SetOwner(this, "ANCHOR_RIGHT");
		GameTooltip:SetText(DailyTrackerStrings.OutOfDateMsg);
		GameTooltipTextLeft1:SetTextColor(1, 1, 1);
		GameTooltip:AddLine(DailyTrackerFrame_OutOfDateText);
		GameTooltip:Show();
	end
end

function DailyTrackerFrame_UpdateLatestVersion()	
	local latestProtocol = DailyTrackerComm.LatestProtocol;
	local latestVersion = DailyTrackerComm.LatestVersion;
	
	-- uncomment to test out of date message
	-- latestProtocol = "";
	-- latestVersion = 99999;
	
	if DailyTrackerComm.ProtocolVersion == latestProtocol then
		DailyTrackerLatestVersion:SetTextColor(0.00,0.60,0);
		DailyTrackerFrame_OutOfDateText = DailyTrackerStrings.SameProtocolMsg;
	else
		DailyTrackerLatestVersion:SetTextColor(0.75,0,0);
		DailyTrackerFrame_OutOfDateText = DailyTrackerStrings.DiffProtocolMsg;
	end
	
	if latestVersion > DailyTracker:GetRevision() then
		DailyTrackerLatestVersion:SetText("latest:" .. latestVersion);
	else
		DailyTrackerLatestVersion:SetText("");
	end
end

function DailyTrackerFrame_OnLoad()
	-- bind escape to hide the frame
	tinsert(UISpecialFrames,"DailyTrackerFrame");
	
	-- various frames need to be set to localized text
	DailyTrackerTitleString:SetText( DailyTrackerStrings.AddOnTitle .. " " .. DailyTracker.VersionNo );
	
	-- display revision number
	DailyTrackerRevision:SetText( "r:" .. DailyTracker:GetRevision() );
	DailyTrackerFrame_UpdateLatestVersion();
	
	-- set the category names and default values
	DailyNormal_Category:SetText( DailyTrackerStrings.DailyNormal .. ":" );
	DailyHeroic_Category:SetText( DailyTrackerStrings.DailyHeroic .. ":" );
	DailyFishing_Category:SetText( DailyTrackerStrings.DailyFishing .. ":" );
	DailyCooking_Category:SetText( DailyTrackerStrings.DailyCooking .. ":" );
	DailyBattleground_Category:SetText( DailyTrackerStrings.DailyBattleground .. ":" );
	
	DailyTracker:LoadQuest( nil, DailyNormal_QuestName, DailyNormal_Location );	
	DailyTracker:LoadQuest( nil, DailyHeroic_QuestName, DailyHeroic_Location );
	DailyTracker:LoadQuest( nil, DailyFishing_QuestName, DailyFishing_Location );
	DailyTracker:LoadQuest( nil, DailyCooking_QuestName, DailyCooking_Location );
	DailyTracker:LoadQuest( nil, DailyBattleground_QuestName, DailyBattleground_Location );
end

function DailyTrackerFrame_OnShow()
	DailyTracker:RefreshFrame();
	DailyTrackerComm:SendCategoryRequest("DAILYNORMAL", "DAILYHEROIC", "DAILYFISHING", "DAILYCOOKING", "DAILYBATTLEGROUND");	
	DailyTrackerFrame_UpdateLatestVersion();
	PlaySound("igCharacterInfoOpen");
end

function DailyTrackerFrame_OnHide()
	--put your event handler logic here
	PlaySound("igCharacterInfoClose");
end
		
function DailyTrackerFrame_OnUpdate()
end
		
function DailyTrackerBtnClear_OnClick()
	DailyTracker:Debug("Clearing current quests...");
	DailyTracker:ClearCurrentQuests();
	DailyTracker:RefreshFrame();
end
		